Crate genetic_lander_schema

Crate genetic_lander_schema 

Structs

Bar
Generated files are compatible only with the same version of protobuf runtime.
TrainingRun
Generated files are compatible only with the same version of protobuf runtime.